@@ -11,6 +11,6 @@
 void slog(char*, ...);
 void slogerror(char*);
 void diem(char *message);
-void diep(char *message);
-void dief(char *format, ...);
+void /*@noreturn@*/ diep(char *message);
+void /*@noreturn@*/ dief(char *format, ...);
 #endif
