@@ -6,25 +6,32 @@
 
 struct mailserver_list {
 	char *ip_address;
-	struct mailserver_list *next;
+	/*@null@*/ struct mailserver_list *next;
 };
 
 #ifdef _MXALLOWD_INTERNAL
 int allow_time = 3600,
     queue_num = -1;
+#ifdef PF
+/* file descriptor for /dev/pf */
+int pffd;
+#endif
 bool to_stdout = false,
      rdns_whitelist = true,
      quiet = false,
      stay_in_foreground = false;
-struct mailserver_list 	*fake_mailservers = NULL,
-			*real_mailservers = NULL;
+struct mailserver_list 	*fake_mailservers,
+			*real_mailservers;
 unsigned long blocked_attempts = 0,
 	      successful_connects = 0,
 	      direct_to_fake = 0;
-char *configfile = "/etc/mxallowd.conf";
-pthread_mutex_t resolv_thread_mutex;
-pthread_cond_t resolv_new_cond;
+char *configfile = SYSCONFDIR "/mxallowd.conf";
+pthread_mutex_t resolv_thread_mutex = PTHREAD_MUTEX_INITIALIZER;
+pthread_cond_t resolv_new_cond = PTHREAD_COND_INITIALIZER;
 #else
+#ifdef PF
+extern int pffd;
+#endif
 extern int allow_time;
 extern int queue_num;
 extern bool to_stdout, quiet, rdns_whitelist;
